Details
Matches regardless of case. e.g., POST will match to post
Public fields
pattern
(character) an http method
Methods
MethodPattern$new()
Create a new MethodPattern object
Arguments
pattern
(character) a HTTP method, lowercase
Returns
A new MethodPattern object
MethodPattern$matches()
test if the pattern matches a given http method
Usage
MethodPattern$matches(method)
Arguments
method
(character) a HTTP method, lowercase
MethodPattern$to_s()
Print pattern for easy human consumption
MethodPattern$clone()
The objects of this class are cloneable with this method.
Usage
MethodPattern$clone(deep = FALSE)
Arguments
deep
Whether to make a deep clone.