hash with counter to store requests and count number
of requests made against the stub
Public fields
hash
(list) a list for internal use only, with elements
key, sig, and count
Methods
StubCounter$put()
Register a request by it's key
Arguments
x
an object of class RequestSignature
Returns
nothing returned; registers request & iterates internal counter
StubCounter$count()
Get the count of number of times any matching request has
been made against this stub
StubCounter$clone()
The objects of this class are cloneable with this method.
Usage
StubCounter$clone(deep = FALSE)
Arguments
deep
Whether to make a deep clone.